MessageConversionError

Enum MessageConversionError 

pub enum MessageConversionError {
    InvalidOptionValue(Option<CoapOptionType>, OptionValueError),
    InvalidOptionForMessageType(CoapOptionType),
    NonRepeatableOptionRepeated(CoapOptionType),
    NotACoapUri(UriParsingError),
    InvalidUri(ParseError),
    InvalidMessageCode(MessageCodeError),
    DataInEmptyMessage,
    MissingToken,
    MissingMessageId,
    InvalidOptionCombination(CoapOptionType, CoapOptionType),
    CriticalOptionUnrecognized,
    Unknown,
}

Variants



InvalidOptionValue(Option<CoapOptionType>, OptionValueError)

Value of an option is invalid.



InvalidOptionForMessageType(CoapOptionType)

Message has an option that is specific for another message type (i.e., request option in response message).



NonRepeatableOptionRepeated(CoapOptionType)

Non-repeatable option was repeated.



NotACoapUri(UriParsingError)

Provided URI has invalid scheme.



InvalidUri(ParseError)

URI is invalid (most likely a Proxy URI cannot be parsed as a valid URL).



InvalidMessageCode(MessageCodeError)

Invalid message code.



DataInEmptyMessage

A message with code 0.00 (Empty) contains data.



MissingToken

Message has no token.



MissingMessageId

Message has no ID.



InvalidOptionCombination(CoapOptionType, CoapOptionType)

Two (or more) options were combined which must not be combined (e.g., Proxy-Scheme and Proxy-URI).



CriticalOptionUnrecognized

A critical option (as defined in RFC 7252 was not recognized).



Unknown

Unknown error inside of libcoap.