CoapMessage

Struct CoapMessage 

pub struct CoapMessage { /* private fields */ }
Representation of a CoAP message.

Implementations

Source

impl CoapMessage

pub fn new(type_: CoapMessageType, code: CoapMessageCode) -> CoapMessage

Creates a new CoAP message with the given type and code.

pub unsafe fn from_raw_pdu( raw_pdu: *const coap_pdu_t, ) -> Result<CoapMessage, MessageConversionError>

Parses the given raw coap_pdu_t into a CoapMessage.

Safety

raw_pdu must point to a valid instance of coap_pdu_t.

pub fn into_raw_pdu<'a, S: CoapSessionCommon<'a> + ?Sized>( self, session: &S, ) -> Result<*mut coap_pdu_t, MessageConversionError>

Converts this message into a raw PDU suitable for sending using the raw coap_send() function.

The caller is responsible for freeing the returned PDU, either by calling coap_send() or coap_delete_pdu().