#[non_exhaustive]#[repr(u16)]pub enum CoapOptionType {
Show 21 variants
IfMatch = 1,
UriHost = 3,
ETag = 4,
IfNoneMatch = 5,
UriPort = 7,
LocationPath = 8,
UriPath = 11,
ContentFormat = 12,
MaxAge = 14,
UriQuery = 15,
Accept = 17,
LocationQuery = 20,
ProxyUri = 35,
ProxyScheme = 39,
Size1 = 60,
Size2 = 28,
Block1 = 27,
Block2 = 23,
HopLimit = 16,
NoResponse = 258,
Observe = 6,
}Expand description
CoAP option types as defined in RFC 7252, Section 5.10 and later CoAP extensions.
The enum value corresponds to the appropriate option number and can be retrieved using
[value] as u16 or to_raw_option_num().
See https://www.iana.org/assignments/core-parameters/core-parameters.xhtml#option-numbers for a list of option numbers registered with the IANA.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
IfMatch = 1
If-Match option (RFC 7252, Section 5.10.8.1).
UriHost = 3
Uri-Host option (RFC 7252, Section 5.10.1).
ETag = 4
ETag option (RFC 7252, Section 5.10.6).
IfNoneMatch = 5
If-None-Match option (RFC 7252, Section 5.10.8.2).
UriPort = 7
Uri-Port option (RFC 7252, Section 5.10.1).
LocationPath = 8
Location-Path option (RFC 7252, Section 5.10.7).
UriPath = 11
Uri-Path option (RFC 7252, Section 5.10.1).
ContentFormat = 12
Content-Format option (RFC 7252, Section 5.10.3).
MaxAge = 14
Max-Age option (RFC 7252, Section 5.10.5).
UriQuery = 15
Uri-Query option (RFC 7252, Section 5.10.1).
Accept = 17
Accept option (RFC 7252, Section 5.10.4).
LocationQuery = 20
Location-Query option (RFC 7252, Section 5.10.7).
ProxyUri = 35
Proxy-Uri option (RFC 7252, Section 5.10.2).
ProxyScheme = 39
Proxy-Scheme option (RFC 7252, Section 5.10.2).
Size1 = 60
Size1 option (RFC 7959, Section 4).
Size2 = 28
Size2 option (RFC 7959, Section 4).
Block1 = 27
Block1 option (RFC 7959, Section 2.1).
Block2 = 23
Block2 option (RFC 7959, Section 2.1).
HopLimit = 16
Hop-Limit option (RFC 8768, Section 3).
NoResponse = 258
No-Response option (RFC 7967, Section 2).
Observe = 6
Observe option (RFC 7641, Section 2).
Implementations
Sourceimpl CoapOptionType
impl CoapOptionType
Sourcepub fn to_raw_option_num(self) -> coap_option_num_t
pub fn to_raw_option_num(self) -> coap_option_num_t
Returns the option number this type belongs to.